package com.diagbot.facade;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.InquiryTriageDTO;
import com.diagbot.dto.SaveInquiryTriageDTO;
import com.diagbot.entity.Client;
import com.diagbot.entity.InquiryTriage;
import com.diagbot.entity.JSONResponseBean;
import com.diagbot.entity.Request;
import com.diagbot.entity.Response;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.InquiryTriageService;
import com.diagbot.service.impl.InquiryTriageServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.FastJsonUtils;
import com.diagbot.util.GsonUtil;
import com.diagbot.util.HttpUtils;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.HospitalVO;
import com.diagbot.vo.InquiryTriageMechVO;
import com.diagbot.vo.SaveInquiryTriageVO;
import com.google.common.collect.Lists;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.swing.text.Utilities;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: wangfeng
 * @time: 2020/3/23 10:33
 */
@Component
@Slf4j
public class InquiryTriageFacade extends InquiryTriageServiceImpl {

    @Autowired
    OptInfoFacade optInfoFacade;
    @Value("${nalizx.apiUrl}")
    private String apiUrl;
    @Value("${nalizx.appKey}")
    private String appKey;
    @Value("${nalizx.appSecret}")
    private String appSecret;

    /**
     * @param saveInquiryVO
     * @return
     */
    public SaveInquiryTriageDTO saveInquiry(SaveInquiryTriageVO saveInquiryVO) {
        if (StringUtil.isBlank(saveInquiryVO.getHospitalCode())) {
            saveInquiryVO.setHospitalCode("朗通通用");
        }
        Date now = DateUtil.now();
        InquiryTriage inquiryInfo = new InquiryTriage();
        BeanUtil.copyProperties(saveInquiryVO, inquiryInfo);
        inquiryInfo.setGmtCreate(now);
        inquiryInfo.setGmtModified(now);
        inquiryInfo.setDisDept(GsonUtil.toJson(saveInquiryVO.getDisDeptist()));
        inquiryInfo.setIp(HttpUtils.getIpAddress());
        boolean res = save(inquiryInfo);

        HospitalVO hospitalVO = new HospitalVO();
        hospitalVO.setHospitalCode(saveInquiryVO.getHospitalCode());
        hospitalVO.setSysType(saveInquiryVO.getSysType());
        // 保存记录表
        optInfoFacade.saveOptOnfo(hospitalVO, "2");
        //邵逸夫医院 心理测试 对接纳里时，返回url
        SaveInquiryTriageDTO saveInquiryDTO = new SaveInquiryTriageDTO();


        if (saveInquiryVO.getHospitalCode().equals("邵逸夫医院")
                && saveInquiryVO.getIdType().equals(1)) {
            //去咨询
            List<String> naliRetList = getUrl(saveInquiryVO);
            String retUrl = naliRetList.get(0);
            saveInquiryDTO.setBody(retUrl);
            saveInquiryDTO.setResponse(naliRetList.get(1));
            saveInquiryDTO.setRequest(naliRetList.get(2));
            saveInquiryDTO.setRequestBodys(naliRetList.get(3));
        }else if(saveInquiryVO.getHospitalCode().equals("邵逸夫医院")
                && saveInquiryVO.getIdType().equals(2)){
            //去挂号。
            //TODO
        }
        return saveInquiryDTO;
    }

    public List<InquiryTriageDTO> getInquirysByMech(InquiryTriageMechVO inquiryTriageMechVO) {
        QueryWrapper<InquiryTriage> inquiryTriageQuery = new QueryWrapper<>();
        inquiryTriageQuery.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id_num", StringUtil.isNotBlank(inquiryTriageMechVO.getIdNum()));
        List<InquiryTriage> data = list(inquiryTriageQuery);

        List<InquiryTriageDTO> dataNew = new ArrayList<InquiryTriageDTO>();
        //过滤
        dataNew = BeanUtil.listCopyTo(data, InquiryTriageDTO.class);
        return dataNew;
    }
    private List<String> getUrl(SaveInquiryTriageVO saveInquiryVO) {
        //TODO 待定
        List<String> ret = Lists.newArrayList();
        String retUrl = null;
        Request request = null;
        Response response = null;
        try {
            String encodingAesKey = "";
            Client client = new Client(apiUrl, appKey, appSecret, encodingAesKey);
            request = getltcs(saveInquiryVO);
            response = client.execute(request);
            log.info("request:" + FastJsonUtils.getBeanToJson(request));
            log.info("requestBodys:" + FastJsonUtils.getBeanToJson(request.getBodys()));
            log.info("response：" + FastJsonUtils.getBeanToJson(response));
            if (response.isSuccess()) {
                JSONResponseBean result = response.getJsonResponseBean();
                retUrl = result.getBody().toString();
            }
        } catch (Exception e) {
        }
        ret.add(retUrl);
        ret.add(FastJsonUtils.getBeanToJson(response));
        ret.add(FastJsonUtils.getBeanToJson(request));
        ret.add(FastJsonUtils.getBeanToJson(request.getBodys()));
        return ret;
    }
    private Request getltcs(SaveInquiryTriageVO saveInquiryVO) {
        List bodyList = new ArrayList<>();



        Map<String, Object> body = new HashMap<>();
        body.put("disDeptist",saveInquiryVO.getDisDeptist() );
        //body.put("patName", saveInquiryVO.getPatName());
        body.put("patAge", saveInquiryVO.getPatAge());
        body.put("patSex", saveInquiryVO.getPatSex());
        body.put("idType", saveInquiryVO.getIdType());
        body.put("symptom", saveInquiryVO.getSymptom());
        body.put("supplement", saveInquiryVO.getSupplement());

        bodyList.add(body);

        //X-Service-Id对应的值
        String serviceId = "consult.questionRecordService";
        //X-Service-Method对应的值
        String method = "saveQuestionRecord";
        return new Request(serviceId, method, bodyList);
    }


}